﻿using System;

using DevExpress.Data.Filtering;
using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.gridView.InitializeView
            (
                true,                          // Multi Select
                GridMultiSelectMode.RowSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,  // Draw Focus Rect Style
                true,                          // Show Indicator
                true,                          // Show Column Headers
                true,                          // Allow Column Moving
                true,                          // Allow Column Resizing
                true,                          // Allow Filter
                true,                          // Allow Sort
                false,                         // Allow Cell Merge
                EditorShowMode.Default,        // Editor Show Mode
                false                          // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridControl.DataSource = new nwindDataSetTableAdapters.OrdersTableAdapter().GetData();

            this.gridView.BestFitColumns();

            this.gridView.ShowFilterPopupDate += gridView_ShowFilterPopupDate;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 그리드 뷰 필터 팝업 일자 표시하기 - gridView_ShowFilterPopupDate(sender, e)

        /// <summary>
        /// 그리드 뷰 필터 팝업 일자 표시하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_ShowFilterPopupDate(object sender, FilterPopupDateEventArgs e)
        {
            if(e.Column.FieldName != "OrderDate")
            {
                return;
            }

            e.List.Clear();

            DateTime firstDate1995 = new DateTime(1995, 1, 1);
            DateTime firstDate1996 = new DateTime(1996, 1, 1);

            CriteriaOperator fromCriteriaOperator = new BinaryOperator
            (
                e.Column.FieldName,
                firstDate1995,
                BinaryOperatorType.GreaterOrEqual
            );

            CriteriaOperator toCriteriaOperator = new BinaryOperator
            (
                e.Column.FieldName,
                firstDate1996,
                BinaryOperatorType.Less
            );

            CriteriaOperator criteriaOperator = new GroupOperator
            (
                GroupOperatorType.And,
                fromCriteriaOperator,
                toCriteriaOperator
            );

            e.List.Add(new FilterDateElement("1995년도", "", criteriaOperator));
        }

        #endregion
    }
}